var Residue_8h =
[
    [ "Residues", "Residue_8h.html#adef1f0673deb36f39288f351b2244645", null ],
    [ "ResidueType", "Residue_8h.html#a8ab7e3833acff514ce94f72d3883b100", null ],
    [ "ResidueTypes", "Residue_8h.html#aa78af3d41e507cc3737981f7ee08c2c1", null ],
    [ "get_next_residue", "Residue_8h.html#a2cadcc607aa4c1f8b1ec4c0c8d493312", null ],
    [ "get_one_letter_code", "Residue_8h.html#a6bf9912d67e4c9d6a134930015a928de", null ],
    [ "get_previous_residue", "Residue_8h.html#ad329e5c66a8de2f49304492c5a690d90", null ],
    [ "get_residue_type", "Residue_8h.html#a4069a6db716b4d4a269df0aed8db5287", null ],
    [ "GLY", "Residue_8h.html#aea45f47684f4d3f1dad7dd1d5f7e7afd", null ],
    [ "UNK", "Residue_8h.html#ac14880d5a13db9545031a99ba1003314", null ]
];